==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/el.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
"Activity" => "Δραστηριότητα",
"A file or folder has been <strong>shared</strong>" => "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Ένα νέο αρχείο ή φάκελος <strong>δημιουργήθηκε</strong> σε ένα διαμοιραζόμενο φάκελο",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Ένα αρχείο ή φάκελος <strong>τροποποιήθηκε</strong> σε ένα διαμοιραζόμενο φάκελο",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Ένα αρχείο ή φάκελος <strong>διεγράφει</strong> από ένα διαμοιραζόμενο φάκελο",
"You created %1\$s" => "Δημιουργήσατε %1\$s",
"%2\$s created %1\$s" => "Ο %2\$s δημιούργησε %1\$s",
"You changed %1\$s" => "Αλλάξατε %1\$s",
"%2\$s changed %1\$s" => "Ο %2\$s άλλαξε %1\$s",
"You deleted %1\$s" => "Διαγράψατε %1\$s",
"%2\$s deleted %1\$s" => "Ο %2\$s διέγραψε %1\$s",
"You shared %1\$s with %2\$s" => "Διαμοιραστήκατε το %1\$s με %2\$s",
"You shared %1\$s with group %2\$s" => "Διαμοιραστήκατε %1\$s με την ομάδα %2\$s",
"%2\$s shared %1\$s with you" => "Ο %2\$s διαμοιράστηκε το %1\$s με εσάς",
"Activity notification" => "Ειδοποίηση δραστηριότητας",
"All Activities" => "Όλες οι Δραστηριότητες",
"Activities by you" => "Δραστηριότητες από εσάς",
"Activities by others" => "Δραστηριότητες από άλλους",
"Shares" => "Κοινόχρηστοι φάκελοι",
"Files" => "Αρχεία",
"%s and %s" => "%s και %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s και <strong class=\"tooltip\" title=\"%s\"> %n περισσότερο</strong>","%s και <strong class=\"tooltip\" title=\"%s\"> %n περισσότερα</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s και %n περισσότερο","%s και %n περισσότερα"),
"Hello %s," => "Καλωσήρθατε %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Λαμβάνετε αυτό το μήνυμα ηλ. ταχυδρομείου γιατί την τελευταία ώρα τα παρακάτω γεγονότα συνέβησαν στο %s",
"You are receiving this email because in the last day the following things happened at %s" => "Λαμβάνετε αυτό το μήνυμα ηλ. ταχυδρομείου γιατί την τελευταία ημέρα τα παρακάτω γεγονότα συνέβησαν στο %s",
"You are receiving this email because in the last week the following things happened at %s" => "Λαμβάνετε αυτό το μήνυμα ηλ. ταχυδρομείου γιατί την τελευταία εβδομάδα τα παρακάτω γεγονότα συνέβησαν στο %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Θα δείτε εδώ μια λίστα από συμβάντα όταν ξεκινήσετε να χρησιμοποιείτε το %s σας.",
"No more events to load" => "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση",
"Enable RSS feed" => "Ενεργοποίηση ροής RSS",
"Notifications" => "Ειδοποιήσεις",
"Mail" => "Ταχυδρομείο",
"Stream" => "Ροή",
"You need to set up your email address before you can receive notification emails." => "Πρέπει να ρυθμίσετε τη διεύθυνση ηλ. ταχυδρομείου σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω ηλ. ταχυδρομείου.",
"Send emails:" => "Αποστολή μηνυμάτων ηλ. ταχυδρομείου:",
"Hourly" => "Ωριαίως",
"Daily" => "Καθημερινώς",
"Weekly" => "Εβδομαδιαίως",
"Activity feed" => "Ροή Δραστηριότητας",
"Personal activity feed for %s" => "Προσωπική ροή δραστηριότητας για %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/el.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
"Activity" => "Δραστηριότητα",
"A file or folder has been <strong>shared</strong>" => "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
"A new file or folder has been <strong>created</strong>" => "Ένα νέο αρχείο ή κατάλογος έχουν <strong>δημιουργηθεί</strong>",
"A file or folder has been <strong>changed</strong>" => "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
"A file or folder has been <strong>deleted</strong>" => "Ένα αρχείο ή κατάλογος έχουν <strong>διαγραφεί</strong>",
"You created %1\$s" => "Δημιουργήσατε %1\$s",
"%2\$s created %1\$s" => "Ο %2\$s δημιούργησε %1\$s",
"You changed %1\$s" => "Αλλάξατε %1\$s",
"%2\$s changed %1\$s" => "Ο %2\$s άλλαξε %1\$s",
"You deleted %1\$s" => "Διαγράψατε %1\$s",
"%2\$s deleted %1\$s" => "Ο %2\$s διέγραψε %1\$s",
"You shared %1\$s with %2\$s" => "Διαμοιραστήκατε το %1\$s με %2\$s",
"You shared %1\$s with group %2\$s" => "Διαμοιραστήκατε %1\$s με την ομάδα %2\$s",
"%2\$s shared %1\$s with you" => "Ο %2\$s διαμοιράστηκε το %1\$s με εσάς",
"You shared %1\$s via link" => "Μοιραστήκατε %1\$s μέσω συνδέσμου",
"Activity notification" => "Ειδοποίηση δραστηριότητας",
"All Activities" => "Όλες οι Δραστηριότητες",
"Activities by you" => "Δραστηριότητες από εσάς",
"Activities by others" => "Δραστηριότητες από άλλους",
"Shares" => "Κοινόχρηστοι φάκελοι",
"Files" => "Αρχεία",
"%s and %s" => "%s και %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s και <strong class=\"tooltip\" title=\"%s\"> %n περισσότερο</strong>","%s και <strong class=\"tooltip\" title=\"%s\"> %n περισσότερα</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s και %n περισσότερο","%s και %n περισσότερα"),
"Hello %s," => "Καλωσήρθατε %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Λαμβάνετε αυτό το μήνυμα ηλ. ταχυδρομείου γιατί την τελευταία ώρα τα παρακάτω γεγονότα συνέβησαν στο %s",
"You are receiving this email because in the last day the following things happened at %s" => "Λαμβάνετε αυτό το μήνυμα ηλ. ταχυδρομείου γιατί την τελευταία ημέρα τα παρακάτω γεγονότα συνέβησαν στο %s",
"You are receiving this email because in the last week the following things happened at %s" => "Λαμβάνετε αυτό το μήνυμα ηλ. ταχυδρομείου γιατί την τελευταία εβδομάδα τα παρακάτω γεγονότα συνέβησαν στο %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Θα δείτε εδώ μια λίστα από συμβάντα όταν ξεκινήσετε να χρησιμοποιείτε το %s σας.",
"No more events to load" => "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση",
"Enable RSS feed" => "Ενεργοποίηση ροής RSS",
"Notifications" => "Ειδοποιήσεις",
"Mail" => "Ταχυδρομείο",
"Stream" => "Ροή",
"Notify about my own actions" => "Ειδοποίησέ με για τις δράσεις μου",
"You need to set up your email address before you can receive notification emails." => "Πρέπει να ρυθμίσετε τη διεύθυνση ηλ. ταχυδρομείου σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω ηλ. ταχυδρομείου.",
"Send emails:" => "Αποστολή μηνυμάτων ηλ. ταχυδρομείου:",
"Hourly" => "Ωριαίως",
"Daily" => "Καθημερινώς",
"Weekly" => "Εβδομαδιαίως",
"Activity feed" => "Ροή Δραστηριότητας",
"Personal activity feed for %s" => "Προσωπική ροή δραστηριότητας για %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
